
# Class: sensitivity quantifier




URI: [biolink:SensitivityQuantifier](https://w3id.org/biolink/vocab/SensitivityQuantifier)

![img](images/SensitivityQuantifier.png)

## Parents

 *  is_a: [RelationshipQuantifier](RelationshipQuantifier.md)

## Attributes

